package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import java.util.Enumeration;
import java.util.Vector;

public class NameConstraints extends ASN1Encodable {
   private ASN1Sequence permitted;
   private ASN1Sequence excluded;

   public NameConstraints(ASN1Sequence seq) {
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         ASN1TaggedObject var2;
         int var3;
         if ((var3 = (var2 = ASN1TaggedObject.getInstance(seq1.nextElement())).getTagNo()) != 0) {
            if (var3 == 1) {
               this.excluded = ASN1Sequence.getInstance(var2, false);
            }
         } else {
            this.permitted = ASN1Sequence.getInstance(var2, false);
         }
      }

   }

   public NameConstraints(Vector permitted, Vector excluded) {
      if (permitted != null) {
         this.permitted = this.createSequence(permitted);
      }

      if (excluded != null) {
         this.excluded = this.createSequence(excluded);
      }

   }

   private DERSequence createSequence(Vector subtree) {
      ASN1EncodableVector var2;
      var2 = new ASN1EncodableVector.<init>();
      Enumeration subtree1 = subtree.elements();

      while(subtree1.hasMoreElements()) {
         var2.add((GeneralSubtree)subtree1.nextElement());
      }

      return new DERSequence(var2);
   }

   public ASN1Sequence getPermittedSubtrees() {
      return this.permitted;
   }

   public ASN1Sequence getExcludedSubtrees() {
      return this.excluded;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      ASN1Sequence var2;
      if ((var2 = this.permitted) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      ASN1Sequence var4;
      if ((var4 = this.excluded) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
